@@ -7,3 +7,5 @@ class ConfigFormat(Enum):
     JSON = auto()
     YAML = auto()
     TOML = auto()
+    CONF = auto()
+    INI = auto()
